@@ -78,25 +78,24 @@ write.bed.matrix <- function(x, basename, bed = paste(basename, ".bed", sep=""),
 
 read.vcf <- function(filename, max.snps, verbose = getOption("gaston.verbose",TRUE)) {
   filename <- path.expand(filename)
-  xx <- vcf_open(filename)
+  xx <- WhopGenome::vcf_open(filename)
   if(is.null(xx)) stop("File not found")
-  samples <- vcf_getsamples(xx) 
-  vcf_selectsamples( xx, samples )
+  samples <- WhopGenome::vcf_getsamples(xx) 
+  WhopGenome::vcf_selectsamples( xx, samples )
 
-  d <- ""
-  f <- function() vcf_readLineRaw(xx, d) 
+  f <- function() WhopGenome::vcf_readLineRaw(xx) 
 
   if(missing(max.snps)) {
     if(verbose) cat("Counting diallelic variants\n")
-    max.snps <- .Call("gg_count_dia_vcf", PACKAGE="gaston", f, d)
-    vcf_close(xx);
-    vcf_reopen(xx);
+    max.snps <- .Call("gg_count_dia_vcf", PACKAGE="gaston", f)
+    WhopGenome::vcf_close(xx);
+    WhopGenome::vcf_reopen(xx);
   }
 
   if(verbose) cat("Reading", max.snps, "diallelic variants for", length(samples), "individuals\n");
   
-  L <- .Call("gg_read_vcf", PACKAGE="gaston", f, d, length(samples), max.snps)
-  vcf_close(xx)
+  L <- .Call("gg_read_vcf", PACKAGE="gaston", f, length(samples), max.snps)
+  WhopGenome::vcf_close(xx)
   snp <- data.frame(chr = L$chr, id = L$id, dist = 0, pos = L$pos , A1 = L$A1, A2 = L$A2, stringsAsFactors = FALSE)
   ped <- data.frame(famid = samples, id = samples, father = 0, mother = 0, sex = 0, pheno = NA, stringsAsFactors = FALSE)
   x <- new("bed.matrix", bed = L$bed, snps = snp, ped = ped,
@@ -108,14 +107,13 @@ read.vcf <- function(filename, max.snps, verbose = getOption("gaston.verbose",TR
 }
 
 count.vcf <- function(filename) {
-  xx <- vcf_open(filename)
+  xx <- WhopGenome::vcf_open(filename)
   if(is.null(xx)) stop("File not found")
-  samples <- vcf_getsamples(xx) 
-  vcf_selectsamples( xx, samples )
-  d <- ""
-  f <- function() vcf_readLineRaw(xx, d) 
-  n <- .Call("gg_count_dia_vcf", PACKAGE="gaston", f, d)
-  vcf_close(xx)
+  samples <- WhopGenome::vcf_getsamples(xx) 
+  WhopGenome::vcf_selectsamples( xx, samples )
+  f <- function() WhopGenome::vcf_readLineRaw(xx) 
+  n <- .Call("gg_count_dia_vcf", PACKAGE="gaston", f)
+  WhopGenome::vcf_close(xx)
   n
 }
 
