@@ -1,5 +1,6 @@
 association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)), 
-                             method = "lmm", response = c("quantitative", "binary"), test = c("score", "wald", "lrt"), 
+                             method = c("lm", "lmm"), response = c("quantitative", "binary"), 
+                             test = c("score", "wald", "lrt"), 
                              K, eigenK, beg = 1, end = ncol(x), p = 0, 
                              tol = .Machine$double.eps^0.25, multithreaded = FALSE, ...) {
 
@@ -11,40 +12,45 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
   response <- match.arg(response)
   test <- match.arg(test)
 
-  if(response == "binary" & test != "score") {
-    warning('Binary phenotype and method = "lmm" force test = "score"')
-    test <- "score"
-  }
-
-  if(test == "score") {
-    if(missing(K)) stop("For a score test, argument K is mandatory")
-    # avec le score test on peut gérer les données manquantes
-    if( any(is.na(Y)) ) {
-      w <- !is.na(Y)
-      X <- as.matrix(X[w,])
-      Y <- Y[w]
-      if (is.list(K)) K <- lapply(K, function(x) x[w,w]) else K <- K[w,w]
-      warning(sum(!w), 'individuals with missing phenotype are ignored.\n')
-    } 
-  } else {
-    if(missing(eigenK)) stop("For Wald and LRT tests, argument eigenK is mandatory")
-    if( any(is.na(Y)) ) stop("Can't handle missing data in Y, please recompute eigenK for the individuals with non-missing phenotype")
-    X <- cbind(X, rep(0,nrow(x))) # space for the SNP
-  }
-
+  # random effect
   if(match.arg(method) == "lmm") { # il n'y a que ça pour le moment
+
+    if(response == "binary" & test != "score") {
+      warning('Binary phenotype and method = "lmm" force test = "score"')
+      test <- "score"
+    }
+
+    if(test == "score") {
+      if(missing(K)) stop("For a score test, argument K is mandatory")
+      # avec le score test on peut gérer les données manquantes dans Y
+      if( any(is.na(Y)) ) {
+        w <- !is.na(Y)
+        X <- as.matrix(X[w,])
+        Y <- Y[w]
+        if (is.list(K)) K <- lapply(K, function(x) x[w,w]) else K <- K[w,w]
+        warning(sum(!w), 'individuals with missing phenotype are ignored.\n')
+      } 
+    } else {
+      if(missing(eigenK)) 
+        stop("For Wald and LRT tests, argument eigenK is mandatory")
+      if( any(is.na(Y)) ) 
+        stop("Can't handle missing data in Y, please recompute eigenK for the individuals with non-missing phenotype")
+    }
+
     if(response == "quantitative") { # score (argument K), wald ou lrt (eigen K) possibles
       if(test == "score") {
         model <- lmm.aireml(Y, X = X, K, get.P = TRUE, ... )
         t <- .Call("gg_GWAS_lmm_score", PACKAGE = 'gaston', x@bed, model$Py, model$P, x@mu, beg-1, end-1)
         t$p <- pchisq( t$score, df = 1, lower.tail=FALSE)
       } else if(test == "wald") {
+        X <- cbind(X, 0) # space for the SNP
         if(ncol(x) > 2000 & multithreaded) 
           t <- .Call("gg_GWAS_lmm_wald_mt", PACKAGE = 'gaston', x@bed, x@mu, Y, X, p, eigenK$values, eigenK$vectors, beg-1, end-1, tol)
         else
           t <- .Call("gg_GWAS_lmm_wald", PACKAGE = 'gaston', x@bed, x@mu, Y, X, p, eigenK$values, eigenK$vectors, beg-1, end-1, tol)
         t$p <- pchisq( (t$beta/t$sd)**2, df = 1, lower.tail=FALSE)
       } else { # test == "lrt"
+        X <- cbind(X, 0) # space for the SNP
         if(ncol(x) > 2000 & multithreaded) 
           t <- .Call("gg_GWAS_lmm_lrt_mt", PACKAGE = 'gaston', x@bed, x@mu, Y, X, p, eigenK$values, eigenK$vectors, beg-1, end-1, tol)
         else
@@ -60,5 +66,24 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
       t$p <- pchisq( t$score, df = 1, lower.tail=FALSE)
     }
   }
+
+  # only fixed effects
+  if(match.arg(method) == "lm") {
+    if(response == "quantitative") {
+      if( any(is.na(Y)) ) 
+        stop("Can't handle missing data in Y, please recompute eigenK for the individuals with non-missing phenotype")
+      if(p > 0)
+        Q <- qr.Q(qr(cbind(eigenK$vectors[,seq_len(p)], X)))
+      else
+        Q <- qr.Q(qr(X))
+      t <- .Call("gg_GWAS_lm_quanti", PACKAGE = 'gaston', x@bed, x@mu, Y, Q, beg-1, end-1);
+      t$p <- pt( abs(t$beta/t$sd), df = length(Y) - ncol(Q) - 1, lower.tail=FALSE)*2
+    }
+    if(response == "binary") {
+      stop("logistic regression not yet available\n")
+    }
+  }
+
+
   return(data.frame(t))
 }
